import java.text.SimpleDateFormat;

import java.util.Map;
import java.util.Random;

import uws.UWSException;

import uws.job.AbstractJob;

/**
 * <p>
 * 	This algorithm must reorder an array of integer. Its values are function of its size: size=4 => {1,2,3,4}, size=7 => {1,2,3,4,5,6,7}, ...
 * 	By default, these values are mixed. The algorithm must permute the array[i] first values until array[i] = i+1.
 * </p>
 * <p>This algorithm is based on the algorithm of V. Chvatal:</p>
 * <pre>
 * 	while(array[1]!=1)
 * 		permute the first array[1] values
 * </pre>
 */
public class JobChvatal extends AbstractJob {
	private static final long serialVersionUID = 1L;
	
	protected int max = 10;

	public JobChvatal(Map<String, String> lstParam) throws UWSException {
		super(lstParam);
		setDateFormat(new SimpleDateFormat("dd/MM/yyyy HH:mm:ss.SSS"));
	}

	@Override
	protected synchronized String generateJobId() {
		return "Chvatal_"+super.generateJobId();
	}

	@Override
	protected void jobWork() throws UWSException, InterruptedException {
		long count = 0;
		int[] sigma = new int[max];
		
		// Create the integers array:
		for(int i=0; !thread.isInterrupted() && i<max; i++)
			sigma[i] = i+1;
		
		// Switch each item of the array:
		for(int i=0;  !thread.isInterrupted() && i<max*max; i++){
			Random rand = new Random();
			int src = rand.nextInt(max), dest = rand.nextInt(max);
			int tmp = sigma[src];
			sigma[src] = sigma[dest];
			sigma[dest] = tmp;
		}
		
		// Apply the algorithm of V. Chvàtal to sort the array::
		String sortedArray = "[";
		for(int i=0; !thread.isInterrupted() && i < sigma.length; i++){
			while(!thread.isInterrupted() && sigma[i] != i+1){
				int indMax = sigma[i];
				for(int j=0; j<(indMax-i)/2; j++){
					int temp = sigma[i+j];
					sigma[i+j] = sigma[indMax-j-1];
					sigma[indMax-j-1] = temp;
					count++;
				}
			}
			sortedArray += ((i==0)?"":"; ")+sigma[i];
		}
		if (!thread.isInterrupted()){
			additionalParameters.put("COUNT", count+" permutations !");
			additionalParameters.put("RESULT", sortedArray+"]");
		}else
			throw new InterruptedException();
	}

	@Override
	protected boolean loadAdditionalParams() throws UWSException {
		if (additionalParameters.containsKey("max")){
			try{
				max = Integer.parseInt(additionalParameters.get("max"));
				if (max < 10)
					max = 10;
			}catch(NumberFormatException nfe){
				throw new UWSException(UWSException.BAD_REQUEST, "The given MAX value (\""+additionalParameters.get("max")+"\") is incorrect: it must be a positive integer value !");
			}
		}
		
		return true;
	}

}
