import java.util.Map;

import uws.UWSException;
import uws.job.AbstractJob;

/**
 * <p>Implementation of the algorithm of Syracuse also known as the problem of 3x+1. There, is the algorithm:</p>
 * <pre>
 * if (n==1)
 * 	return 1;
 * else{
 * 	if (n%2 == 0)
 * 		return f(n/2);
 * 	else
 * 		return f(3n+1);
 * 	}</pre
 * 
 * <i><u>Note:</u> this algorithm has been implemented here in a non-recursive manner !</i>
 */
public class JobSyracuse extends AbstractJob {
	private static final long serialVersionUID = 1L;
	
	protected int n = 1;

	public JobSyracuse(Map<String, String> lstParam) throws UWSException {
		super(lstParam);
	}

	@Override
	protected synchronized String generateJobId() {
		return "Syracuse_"+super.generateJobId();
	}

	@Override
	protected void jobWork() throws UWSException, InterruptedException {
		long count = 0;
		while(!thread.isInterrupted() && n != 1){
			if ( n % 2 == 0)
				n = n / 2;
			else
				n = 3*n + 1;
			count++;
		}
		if (!thread.isInterrupted())
				additionalParameters.put("RESULT", "Finished in "+count+" iterations !");
		else
			throw new InterruptedException();
	}

	@Override
	protected boolean loadAdditionalParams() throws UWSException {
		if (additionalParameters.containsKey("nsyracuse")){
			try{
				n = Integer.parseInt(additionalParameters.get("nsyracuse"));
				if (n <= 0)
					n = 1;
			}catch(NumberFormatException nfe){
				throw new UWSException(UWSException.BAD_REQUEST, "The given NSYRACUSE value (\""+additionalParameters.get("nsyracuse")+"\") is incorrect: it must be a positive integer value !");
			}
		}
		return true;
	}

}
