import java.io.File;
import java.io.IOException;

import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import uws.UWSException;
import uws.UWSToolBox;

import uws.job.JobList;

import uws.service.ExtendedUWS;
import uws.service.controller.DestructionTimeController;
import uws.service.controller.ExecutionDurationController;
import uws.service.controller.DestructionTimeController.DateField;

public class UWSAlgorithms extends HttpServlet {
	private static final long serialVersionUID = 1L;

	protected ExtendedUWS uws = null;
	protected File restoreFile = null;
	
	@Override
	public void init(ServletConfig config) throws ServletException {
		super.init(config);
		
		ServletContext context = config.getServletContext();
		
	// Try to restore the last saved UWS:
		restoreFile = new File(context.getRealPath("/"), "uwsRestore2");
		uws = (ExtendedUWS) UWSToolBox.restoreUWS(restoreFile, true);
		
	// If no retrieved UWS:
		if (uws == null){
			try{
				String contextPath = context.getContextPath();
				
				// Create our UWS (with a user identification):
				uws = new MyExtendedUWS(3);

				// Set the destruction time for all jobs:
				DestructionTimeController destController = uws.getDestructionTimeController();
				destController.setDefaultDestructionInterval(1, DateField.MONTH);				// = job destroyed 1 month after its creation
				destController.allowModification(false);										// = no modification
				
				// Set the execution time for all jobs:
				ExecutionDurationController execController = uws.getExecutionDurationController();
				execController.setDefaultExecutionDuration(3600);								// = job execution limited to 3600s (1 hour)
				execController.allowModification(false);										// = no modification
				
				// Set the UWS home page:
				uws.setHomePage(contextPath+"/extended.html");
				
				// Sets the XSLT URL:
				uws.setXsltURL(contextPath+"/styles/uws.xsl");
				
				// Create 3 jobs lists:
				uws.addJobList(new JobList<JobChvatal>("chvatals"), JobChvatal.class);
				uws.addJobList(new JobList<JobSyracuse>("syracuses"), JobSyracuse.class);
				uws.addJobList(new JobList<JobAckerman>("ackermans"), JobAckerman.class);
			}catch(UWSException ex){
				throw new ServletException(ex);
			}
		}
	}

	@Override
	public void destroy() {
		// Save the current state of this UWS:
		UWSToolBox.saveUWS(uws, restoreFile, true);
		super.destroy();
	}
	
	@Override
	protected void service(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
		try{
			// FORWARD THE REQUEST TO THE UWS:
			boolean done = uws.executeRequest(req, resp);
			
			System.out.println("### [UWS INFO - "+uws.getName()+"] : REQUEST \""+uws.getExecutedAction()+"\" ? "+(done?"OK":"NOT DONE")+"\t(format="+uws.getChoosenSerializer()+") ###");
			
		}catch(UWSException uwsEx){
			// Display properly the caught UWSException:
			resp.sendError(uwsEx.getHttpErrorCode(), uwsEx.getMessage());
		}
	}
	
}
