<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:uws="http://www.ivoa.net/xml/UWS/v1.0" xmlns:vosi="http://www.ivoa.net/xml/Availability/v0.4" xmlns:fn="http://www.w3.org/2005/xpath-functions/#">
	<xsl:output method="html" media-type="text/html" encoding="UTF-8" version="4.0" />
	
	<xsl:template match="uws:jobList | jobList">
		<html>
			<head>
				<link href="/uwsExamples/styles/uwstuto.css" rel="stylesheet" type="text/css" />
				<title>Jobs list <xsl:value-of select="@name" /></title>
			</head>
			<body>
				<div id="navigationBar">
					<ul>
						<li><a href="/uwsExamples/extended" title="The UWS Algorithms">Parent</a></li>
						<li><a href="/uwsExamples">Home</a></li>
						<li><a href="/uwsExamples/basic.html">UWS example: Timers</a></li>
						<li><a href="/uwsExamples/extended/">UWS example: Algorithms</a></li>
						<li class="logo"><a href="http://astro.u-strasbg.fr/"><img src="/uwsExamples/images/cds.png" alt="CDS Icon" title="Centre de Données astronomiques de Strasbourg" /></a></li>
						<li class="logo" style="border-left: solid 1px white;"><a href="http://www.ivoa.net/"><img src="/uwsExamples/images/ivoa.png" alt="IVOA Icon" title="International Virtual Observatory Alliance" /></a></li>
					</ul>
				</div>
				
				<div id="content">
					<h1>Jobs list <i><xsl:value-of select="@name" /></i></h1>
					<ul>
						<xsl:for-each select="uws:jobRef | jobRef">
							<li>
								<xsl:element name="a">
									<xsl:attribute name="href">
										<xsl:value-of select="@xlink:href | @href" />
									</xsl:attribute>
									Job N°<xsl:value-of select="@id"/>
								</xsl:element>
								<ul style="list-style-type: square">
									<li><xsl:apply-templates select="uws:phase | phase"/></li>
									<li>
										<xsl:element name="form">
											<xsl:attribute name="action">
												<xsl:value-of select="../@name" />/<xsl:value-of select="@id" />
											</xsl:attribute>
											<xsl:attribute name="method">post</xsl:attribute>
											<xsl:element name="input">
												<xsl:attribute name="type">hidden</xsl:attribute>
												<xsl:attribute name="name">ACTION</xsl:attribute>
												<xsl:attribute name="value">DELETE</xsl:attribute>
											</xsl:element>
											<xsl:element name="input">
												<xsl:attribute name="type">submit</xsl:attribute>
												<xsl:attribute name="value">Destroy</xsl:attribute>
											</xsl:element>
										</xsl:element>
									</li>
								</ul>
							</li>	
						</xsl:for-each>
					</ul>
				</div>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="uws:job | job">
		<html>
			<head>
				<link href="/uwsExamples/styles/uwstuto.css" rel="stylesheet" type="text/css" />
				<title>Job <xsl:value-of select="uws:jobId | jobId" /></title>
			</head>
			<body>
				<div id="navigationBar">
					<ul>
						<li><a href="." title="">Parent</a></li>
						<li><a href="/uwsExamples">Home</a></li>
						<li><a href="/uwsExamples/basic.html">UWS example: Timers</a></li>
						<li><a href="/uwsExamples/extended/">UWS example: Algorithms</a></li>
						<li class="logo"><a href="http://astro.u-strasbg.fr/"><img src="/uwsExamples/images/cds.png" alt="CDS Icon" title="Centre de Données astronomiques de Strasbourg" /></a></li>
						<li class="logo" style="border-left: solid 1px white;"><a href="http://www.ivoa.net/"><img src="/uwsExamples/images/ivoa.png" alt="IVOA Icon" title="International Virtual Observatory Alliance" /></a></li>
					</ul>
				</div>
				
				<div id="content">
					<h1>
						Job N°<xsl:value-of select="uws:jobId | jobId" />
						<xsl:if test="string-length(uws:runId | runId) > 0">
							(alias <xsl:value-of select="uws:runId | runId" />)
						</xsl:if>
					</h1>
					<div>
						<h3>General description</h3>
						<ul>
							<li><xsl:apply-templates select="uws:ownerId | ownerId" /></li>
							<li><xsl:apply-templates select="uws:quote | quote" /></li>
							<li><xsl:apply-templates select="uws:destruction | destruction" /></li>
						</ul>
					</div>
					<div>
						<h3>Execution</h3>
						<ul>
							<li><xsl:apply-templates select="uws:phase | phase"/></li>
							<li><xsl:apply-templates select="uws:startTime | startTime" /></li>
							<li><xsl:apply-templates select="uws:endTime | endTime" /></li>
							<li><xsl:apply-templates select="uws:executionDuration | executionDuration" /></li>
							<li><xsl:apply-templates select="uws:results | results" /></li>
							<li><xsl:apply-templates select="uws:errorSummary | errorSummary" /></li>
						</ul>
					</div>
					<xsl:apply-templates select="uws:parameters | parameters" />
				</div>
			</body>
		</html>
	</xsl:template>
	
	
	<xsl:template match="uws:jobId | jobId"> 
		<b>Job Identifier: </b><xsl:value-of select="." />
	</xsl:template>
	
	<xsl:template match="uws:runId | runId">
		<b>Run identifier: </b><xsl:value-of select="." />
	</xsl:template>
	
	<xsl:template match="uws:ownerId | ownerId">
		<xsl:choose>
			<xsl:when test="string-length() = 0">
				<b>Owner: </b>None
			</xsl:when>
			<xsl:otherwise>
				<b>Owner: </b><xsl:value-of select="." />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="uws:phase | phase">
		<xsl:element name="form">
			<xsl:attribute name="style">margin-top:1em; margin-bottom:1em;</xsl:attribute>
			<xsl:attribute name="action">
				<xsl:choose>
					<xsl:when test="local-name(..) = 'job'"><xsl:value-of select="../jobId | ../uws:jobId" />/phase</xsl:when>
					<xsl:when test="local-name(..) = 'jobRef'"><xsl:value-of select="../../@name | ../../@name" />/<xsl:value-of select="../@id | ../@id" />/phase</xsl:when>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="method">post</xsl:attribute>
			<b>Phase: </b>
			<xsl:value-of select="." />
			<xsl:choose>
				<xsl:when test=". = 'PENDING'">
					<input type="hidden" id="phase" name="PHASE" value="RUN" />
					<input type="submit" class="standard_button" value="Start" onClick="document.getElementById('phase').value='RUN'" />
					<input type="submit" class="standard_button" value="Abort" onClick="document.getElementById('phase').value='ABORT'" />
				</xsl:when>
				<xsl:when test=". = 'HELD'">
					<input type="hidden" id="phase" name="PHASE" value="RUN" />
					<input type="submit" class="standard_button" value="Start" onClick="document.getElementById('phase').value='RUN'" />
					<input type="submit" class="standard_button" value="Abort" onClick="document.getElementById('phase').value='ABORT'" />
				</xsl:when>
				<xsl:when test=". = 'QUEUED'">
					<input type="hidden" id="phase" name="PHASE" value="ABORT" />
					<input type="button" class="standard_button" value="Refresh" onClick="window.location.reload();" />
					<input type="submit" class="standard_button" value="Abort" onClick="document.getElementById('phase').value='ABORT'" />
				</xsl:when>
				<xsl:when test=". = 'EXECUTING'">
					<input type="hidden" id="phase" name="PHASE" value="ABORT" />
					<input type="button" class="standard_button" value="Refresh" onClick="window.location.reload();" />
					<input type="submit" class="standard_button" value="Abort" onClick="document.getElementById('phase').value='ABORT'" />
				</xsl:when>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="uws:quote | quote">
		<xsl:choose>
			<xsl:when test="string-length() = 0">
				<b>Quote: </b>None
			</xsl:when>
			<xsl:otherwise>
				<b>Quote: </b><xsl:value-of select="." />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="uws:startTime | startTime">
		<xsl:choose>
			<xsl:when test="string-length() = 0">
				<b>Start: </b>Not yet started !
			</xsl:when>
			<xsl:otherwise>
				<b>Start: </b><xsl:value-of select="." />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="uws:endTime | endTime">
		<xsl:choose>
			<xsl:when test="string-length() = 0">
				<b>End: </b>Not yet finished !
			</xsl:when>
			<xsl:otherwise>
				<b>End: </b><xsl:value-of select="." />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="uws:executionDuration | executionDuration">
		<xsl:choose>
			<xsl:when test=". = 0">
				<b>Time out: </b>None
			</xsl:when>
			<xsl:otherwise>
				The execution has to finish in <b><xsl:value-of select="." /> seconds</b> since its beginning !
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:template>
	
	<xsl:template match="uws:destruction | destruction">
		<xsl:choose>
			<xsl:when test="string-length() = 0">
				<b>Destruction: </b>Never
			</xsl:when>
			<xsl:otherwise>
				<b>Destruction: </b><xsl:value-of select="." />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="uws:parameters | parameters">
		<div class="section">
			<h3>Parameters</h3>
			<table border="1" style="margin-left: 2em">
				<tr>
					<th>Name</th>
					<th>Value</th>
				</tr>
				<xsl:for-each select="uws:parameter | parameter">
					<xsl:element name="tr">
						<xsl:if test="position() mod 2 = 0">
							<xsl:attribute name="class">pair</xsl:attribute>
						</xsl:if>
						<td><xsl:value-of select="@id" /></td>
						<td><xsl:value-of select="." /></td>
					</xsl:element>
				</xsl:for-each>
			</table>
		</div>
	</xsl:template>
	
	<xsl:template match="uws:parameter | parameter">
		<p>The value of the parameter "<b><xsl:value-of select="@id" /></b>" is: "<b><xsl:value-of select="." /></b>"</p>
	</xsl:template>
	
	<xsl:template match="uws:results | results">
		<b><xsl:value-of select="count(child::*)" /> Results</b>
		<ul>
			<xsl:for-each select="uws:result | result">
				<li>
					<xsl:element name="a">
						<xsl:attribute name="href">
							<xsl:value-of select="@xlink:href | @href" />
						</xsl:attribute>
						<xsl:value-of select="@id"/>
					</xsl:element>				
				</li>
			</xsl:for-each>
		</ul>
	</xsl:template>
	
	<xsl:template match="uws:errorSummary | errorSummary">
		<xsl:choose>
			<xsl:when test="string-length() = 0">
				<b>UWS error summary: </b>No error !
			</xsl:when>
			<xsl:otherwise>
				<b>UWS error summary: </b><i>A <xsl:value-of select="@type" /> error has occurred:</i><br />
				<xsl:value-of select="uws:message | message" />
				<xsl:if test="@hasDetail = 'true'">
					<br />
					<xsl:element name="a">
						<xsl:attribute name="href"><xsl:value-of select="../uws:jobId | ../jobId" />/error</xsl:attribute>
						Click here to view more details
					</xsl:element>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
</xsl:stylesheet>